@@ -5,11 +5,13 @@ import click
 
 from .cli_auth import auth as auth  # type: ignore
 from .cli_deploy import deploy as deploy  # type: ignore
+from .cli_eval import eval as eval  # type: ignore
 from .cli_init import init as init  # type: ignore
 from .cli_invoke import invoke as invoke  # type: ignore
 from .cli_new import new as new  # type: ignore
 from .cli_pack import pack as pack  # type: ignore
 from .cli_publish import publish as publish  # type: ignore
+from .cli_pull import pull as pull  # type: ignore
 from .cli_push import push as push  # type: ignore
 from .cli_run import run as run  # type: ignore
 
@@ -65,3 +67,5 @@ cli.add_command(deploy)
 cli.add_command(auth)
 cli.add_command(invoke)
 cli.add_command(push)
+cli.add_command(pull)
+cli.add_command(eval)
